#ifndef TCON_DEV_H
   #define TCON_DEV_H

#ifdef __cplusplus
extern "C" { // g++
#endif

#include <stdint.h>

enum libtcon_error{
   LIBTCON_SUCCESS             =  0,
   LIBTCON_ERROR_IO            = -1,
   LIBTCON_ERROR_INVALID_PARAM = -2,
   LIBTCON_ERROR_ACCESS        = -3,
   LIBTCON_ERROR_NO_DEVICE     = -4,
   LIBTCON_ERROR_NOT_FOUND     = -5,
   LIBTCON_ERROR_BUSY          = -6,
   LIBTCON_ERROR_TIMEOUT       = -7,
   LIBTCON_ERROR_OVERFLOW      = -8,
   LIBTCON_ERROR_PIPE          = -9,
   LIBTCON_ERROR_INTERRUPTED   = -10,
   LIBTCON_ERROR_NO_MEM        = -11,
   LIBTCON_ERROR_NOT_SUPPORTED = -12,

   LIBTCON_ERROR_OTHER         = -99
};

// Initial
short tcon_init(void);

// Board Information
short tcon_get_panel_width(short board_id);
short tcon_get_panel_height(short board_id);
short tcon_get_temp(short board_id);
short tcon_get_vcom(short board_id);
uint32_t tcon_get_fw_version(short board_id);

// Load Image
short tcon_ld_img(short board_id, uint8_t* img_data,
                  short width, short height, short startx, short starty);
short tcon_ld_img_rgb(short board_id, uint8_t* img_data_r,
                      uint8_t* img_data_g,  uint8_t* imgdata__b,
                      short width, short height, short startx, short starty);

short tcon_fill_img(short board_id, uint8_t gl, short width, short height,
                    short startx, short starty);
short tcon_fill_img_rgb(short board_id,
                        uint8_t gl_r, uint8_t gl_g, uint8_t gl_b,
                        short width, short height, short startx, short starty);
short tcon_fill_img_all(short board_id, uint8_t gl);
short tcon_fill_img_all_rgb(short board_id,
                            uint8_t gl_r, uint8_t gl_g, uint8_t gl_b);

// Display
short tcon_dpy_img(short board_id, short wf_mode,
                   short width, short heigh, short startx, short starty);
short tcon_dpy_img_all(short board_id, short wf_mode);
short tcon_clr_scr(short board_id);

// Control
short tcon_set_vcom(short board_id, short vcom_val);
short tcon_set_id(short board_id, short new_id);

// Update Firmware/Waveform
short tcon_upd_fw(short board_id, char* filename);
short tcon_upd_wf(short board_id, char* filename);
short tcon_soft_reset(short board_id);

#ifdef __cplusplus
}
#endif

#endif


